var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React from 'react';
import { ForgotPasswordScreen } from '../../screens';
import { cleanup, fireEvent, render, screen, waitFor } from '@testing-library/react-native';
import { AuthContextProvider } from '../../contexts';
import { authContextProviderProps } from '../../testUtils';
import { SafeAreaProvider } from 'react-native-safe-area-context';
import { View } from 'react-native';
afterEach(cleanup);
describe('Forgot Password Screen Tests', () => {
    let mockFunction;
    beforeEach(() => {
        mockFunction = jest.fn();
    });
    afterEach(() => {
        jest.clearAllMocks();
    });
    const renderer = (props) => render(React.createElement(AuthContextProvider, Object.assign({}, authContextProviderProps),
        React.createElement(SafeAreaProvider, null,
            React.createElement(ForgotPasswordScreen, Object.assign({}, props)))));
    it('renders correctly', () => {
        renderer({
            description: (time) => React.createElement(View, null, time),
        });
        expect(screen.getByText('Forgot Password')).toBeOnTheScreen();
    });
    it('should call handleOnClose on click of close icon', () => {
        renderer();
        const closeIcon = screen.getByTestId('blui-workflow-card-header-icon');
        fireEvent.press(closeIcon);
        expect(render).toBeTruthy();
    });
    it('Clicking on Back button test', () => {
        renderer({
            WorkflowCardActionsProps: {
                onPrevious: mockFunction(),
            },
        });
        const prevButton = screen.getByTestId('blui-workflow-card-actions-previous-button');
        fireEvent.press(prevButton);
        expect(mockFunction).toHaveBeenCalled();
    });
    it('Clicking on next button should call handleOnNext callback function', () => __awaiter(void 0, void 0, void 0, function* () {
        renderer();
        const emailInput = screen.getByTestId('blui-forgot-password-textinput');
        const nextButton = screen.getByTestId('blui-workflow-card-actions-next-button-text');
        expect(nextButton).toBeDisabled();
        fireEvent.changeText(emailInput, 'test@eaton.com');
        expect(nextButton).toBeEnabled();
        fireEvent.press(nextButton);
        expect(screen.getByTestId('blui-spinner')).toBeOnTheScreen();
        yield waitFor(() => {
            fireEvent.press(screen.getByText('Done'));
        });
    }));
});
